<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nome_do_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Display help </source>
        <translation>Mostrar ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Back</source>
        <translation>Voltar atrás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>View Log</source>
        <translation>Ver registo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <location filename="../mainwindow.cpp" line="616"/>
        <location filename="../mainwindow.cpp" line="639"/>
        <source>Select ISO</source>
        <translation>Seleccionar ficheiro ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecionar Dispositivo USB a usar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Seleccionar ficheiro ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Opções Avançadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Formatar em ext4 mesmo que já esteja formatado nesse sistema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Guardar o directório boot original ao actualizar uma USB-executável</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Usar particionamento gpt em vez de msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>Particionamento GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Actualizar (actualizar apenas uma USB-executável existente)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Não substituir os ficheiros syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Manter os ficheiros syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorar a verificação USB/removível</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Desactivar temporariamente a montagem automática</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Atribuir o marcador de disco &apos;pmbr_boot&apos; (não iniciará via UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Não usar fuseiso para montar ficheiros iso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Tamanho da partição ESP (uefi):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Verbosity (less to more):</source>
        <translation>Nível de detalhe (de menos para mais):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="506"/>
        <source>Data partition format type</source>
        <translation>Tipo do formato da partição de dados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Make separate data partition (percent)</source>
        <translation>Criar partição de dados separada (percentagem)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Refresh drive list</source>
        <translation>Actualizar a lista de dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Show advanced options</source>
        <translation>Mostrar opções avançadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Modo &amp;completo - USB-executável alterável</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Só de leitura; não pode ser usado com &apos;persistência&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>Modo de I&amp;magem - USB-executável apenas de leitura (dd)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="589"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Para distribuições não antiX/MX usar o modo de imagem (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="637"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Percent of USB-device to use:</source>
        <translation>Parte do dispositivo USB a usar (%):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="682"/>
        <source>Label ext partition:</source>
        <translation>Rotular a partição ext:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="730"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Não executar commandos que afectem o dispositivo USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="733"/>
        <source>Dry run (no change to system)</source>
        <translation>Simulação (não altera o sistema)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="740"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Clonar uma USB-executável ou um ficheiro ISO montados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <source>Clone a mounted live system</source>
        <translation>Clonar um sistema Live</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Definir para arrancar de partição encriptada; pedirá uma frase-senha no primeiro arranque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Encrypt</source>
        <translation>Encriptar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Clone running live system</source>
        <translation>Clonar o sistema externo em execução</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation type="vanished">Confirmação</translation>
    </message>
    <message>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation type="vanished">O dispositivo de destino %1 tem mais do que %2 GB. Proceder?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="570"/>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Failure</source>
        <translation>Falhou</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Origem e destino no mesmo dispositivo; seleccionar de novo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <source>Source Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Could not find the source linuxfs file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Warning: The target device (%1) is smaller than the source (%2). The data might not fit. Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Size Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="151"/>
        <source>The target device %1 is larger than %2 GB.

This may indicate you have selected the wrong device.
Are you sure you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Large Target Device Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation>A gravar %1 usando o comando &apos;dd&apos; em /dev/%2,

Aguarde até que o processo esteja concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>MX Live Usb Maker</source>
        <translation>Criador de Dispositivos USB Executáveis do MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>LiveUSB creation successful!</source>
        <translation>USB-executável (Instalação externa USB) criada com êxito!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Erro no processo de criar a Instalação externa USB-executável</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Please select a USB device to write to</source>
        <translation>Seleccionar o dispositivo USB a usar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Estas acções irão destruir todos os dados em 

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Do you wish to continue?</source>
        <translation>Continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="534"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programa para criar instalações externas USB-executável a partir de ficheiros ISO, de outra instalação externa USB-executável, de CD/DVD-executável ou de um sistema externo em execução.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Seleccionar um ficheiro ISO a instalar na unidade USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="556"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>Ficheiros ISO (*.iso);;Todos os ficheiros (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Select Source Directory</source>
        <translation>Seleccionar Directório Origem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="570"/>
        <source>Could not find linuxfs file</source>
        <translation>O ficheiro linuxfs não foi encontrado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>Hide advanced options</source>
        <translation>Ocultar opções avançadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Select Source</source>
        <translation>Seleccionar Origem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Select ISO file</source>
        <translation>Seleccionar ficheiro ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="631"/>
        <source>clone</source>
        <translation>clonar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="698"/>
        <source>Could not find a log file at: </source>
        <translation>Não encontrado um ficheiro de registo (log) em:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <location filename="../about.cpp" line="85"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programa para criar instalações externas USB-executável a partir de ficheiros ISO, de outra instalação externa USB-executável, de CD/DVD-executável ou de um sistema externo em execução.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation>ficheiro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation>Nome do ficheiro .iso a abrir</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>[filename]</source>
        <translation>[ficheiro]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>O utilizador parece ser o root; para usar este programa, sair e voltar a entrar como utilizador normal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as root.</source>
        <translation>Este programa tem que ser executado como root (administrador).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>version:</source>
        <translation>versão: </translation>
    </message>
</context>
</TS>
